@@ -194,7 +194,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 				self.lastfile = s
 				self.set_title()
 			except Options.OptionError, err:
-				self.set_status(err)
+				self.set_status("Error: " + str(err))
 
 
 	def save_file(self):
@@ -348,7 +348,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			seq.play()
 			self.lastmidi = o.midifile
 		except Options.OptionError, err:
-			self.set_status(err)
+			self.set_status("Error: " + str(err))
 
 		self.ui.startbutton.setEnabled(True)
 		self.ui.stopbutton.setEnabled(False)
